@@ -24,6 +24,10 @@ class Column(object):
         self.data["comment"] = column_schema["COLUMN_COMMENT"]
         self.data["unsigned"] = False
         self.data["type_is_bool"] = False
+        if column_schema["COLUMN_KEY"] == "PRI":
+            self.data["is_primary"] = True
+        else:
+            self.data["is_primary"] = False
 
         if column_schema["COLUMN_TYPE"].find("unsigned") != -1:
             self.data["unsigned"] = True
