@@ -21,6 +21,7 @@ class RowsEvent(BinLogEvent):
 
         #Header
         self.table_id = self._read_table_id()
+        self.primary_key = table_map[self.table_id].data["primary_key"]
         self.flags = struct.unpack('<H', self.packet.read(2))[0]
 
         #Event V2
@@ -34,7 +35,7 @@ class RowsEvent(BinLogEvent):
         self.number_of_columns = self.packet.read_length_coded_binary()
         self.columns = self.table_map[self.table_id].columns
 
-        #Aditionnal informations
+        # Additional information
         self.schema = self.table_map[self.table_id].schema
         self.table = self.table_map[self.table_id].table
 
@@ -62,9 +63,6 @@ class RowsEvent(BinLogEvent):
                     values[name] = struct.unpack("<B", self.packet.read(1))[0]
                 else:
                     values[name] = struct.unpack("<b", self.packet.read(1))[0]
-
-                if column.type_is_bool:
-                    values[name] = bool(values[name])
             elif column.type == FIELD_TYPE.SHORT:
                 if unsigned:
                     values[name] = struct.unpack("<H", self.packet.read(2))[0]
@@ -127,10 +125,10 @@ class RowsEvent(BinLogEvent):
                 # We read set columns as a bitmap telling us which options
                 # are enabled
                 bit_mask = self.packet.read_uint_by_size(column.size)
-                values[name] = {
+                values[name] = set(
                     val for idx, val in enumerate(column.set_values)
                     if bit_mask & 2 ** idx
-                } or None
+                ) or None
 
             elif column.type == FIELD_TYPE.BIT:
                 values[name] = self.__read_bit(column)
@@ -143,7 +141,7 @@ class RowsEvent(BinLogEvent):
         return values
 
     def __add_fsp_to_time(self, time, column):
-        """Read and add the fractionnal part of time
+        """Read and add the fractional part of time
         For more details about new date format:
         http://dev.mysql.com/doc/internals/en/date-and-time-data-type-representation.html
         """
@@ -163,10 +161,10 @@ class RowsEvent(BinLogEvent):
         return time
 
     def __read_string(self, size, column):
-        str = self.packet.read_length_coded_pascal_string(size)
+        string = self.packet.read_length_coded_pascal_string(size)
         if column.character_set_name is not None:
-            str = str.decode(column.character_set_name)
-        return str
+            string = string.decode(column.character_set_name)
+        return string
 
     def __read_bit(self, column):
         """Read MySQL BIT type"""
@@ -505,7 +503,7 @@ class TableMapEvent(BinLogEvent):
         self.table_obj = Table(self.column_schemas, self.table_id, self.schema,
                                self.table, self.columns)
 
-        # TODO: get this informations instead of trashing data
+        # TODO: get this information instead of trashing data
         # n              NULL-bitmask, length: (column-length * 8) / 7
 
     def get_table(self):
