@@ -9,13 +9,36 @@ __all__ = ["TestDataObjects"]
 
 
 class TestDataObjects(base.PyMySQLReplicationTestCase):
-    def test_column(self):
+    def test_column_is_primary(self):
         col = Column(1,
                      {"COLUMN_NAME": "test",
                       "COLLATION_NAME": "utf8_general_ci",
                       "CHARACTER_SET_NAME": "UTF8",
                       "COLUMN_COMMENT": "",
-                      "COLUMN_TYPE": "tinyint(2)"},
+                      "COLUMN_TYPE": "tinyint(2)",
+                      "COLUMN_KEY": "PRI"},
+                     None)
+        self.assertEqual(True, col.is_primary)
+
+    def test_column_not_primary(self):
+        col = Column(1,
+                     {"COLUMN_NAME": "test",
+                      "COLLATION_NAME": "utf8_general_ci",
+                      "CHARACTER_SET_NAME": "UTF8",
+                      "COLUMN_COMMENT": "",
+                      "COLUMN_TYPE": "tinyint(2)",
+                      "COLUMN_KEY": ""},
+                     None)
+        self.assertEqual(False, col.is_primary)
+
+    def test_column_serializable(self):
+        col = Column(1,
+                     {"COLUMN_NAME": "test",
+                      "COLLATION_NAME": "utf8_general_ci",
+                      "CHARACTER_SET_NAME": "UTF8",
+                      "COLUMN_COMMENT": "",
+                      "COLUMN_TYPE": "tinyint(2)",
+                      "COLUMN_KEY": "PRI"},
                      None)
 
         serialized = col.serializable_data()
@@ -26,6 +49,7 @@ class TestDataObjects(base.PyMySQLReplicationTestCase):
         self.assertIn("comment", serialized)
         self.assertIn("unsigned", serialized)
         self.assertIn("type_is_bool", serialized)
+        self.assertIn("is_primary", serialized)
 
         self.assertEqual(col, Column(**serialized))
 
