@@ -1,16 +1,15 @@
 # -*- coding: utf-8 -*-
 
 import copy
-import datetime
 import platform
 import unittest
 
 from decimal import Decimal
 
 from pymysqlreplication.tests import base
-from pymysqlreplication.event import *
 from pymysqlreplication.constants.BINLOG import *
 from pymysqlreplication.row_event import *
+from pymysqlreplication.event import *
 
 __all__ = ["TestDataType"]
 
@@ -21,18 +20,15 @@ class TestDataType(base.PyMySQLReplicationTestCase):
         self.execute(insert_query)
         self.execute("COMMIT")
 
-        #RotateEvent
-        self.stream.fetchone()
-        #FormatDescription
-        self.stream.fetchone()
+        self.assertIsInstance(self.stream.fetchone(), RotateEvent)
+        self.assertIsInstance(self.stream.fetchone(), FormatDescriptionEvent)
         #QueryEvent for the Create Table
-        self.stream.fetchone()
+        self.assertIsInstance(self.stream.fetchone(), QueryEvent)
 
         #QueryEvent for the BEGIN
-        self.stream.fetchone()
+        self.assertIsInstance(self.stream.fetchone(), QueryEvent)
 
-        event = self.stream.fetchone()
-        self.assertIsInstance(event, TableMapEvent)
+        self.assertIsInstance(self.stream.fetchone(), TableMapEvent)
 
         event = self.stream.fetchone()
         if self.isMySQL56AndMore():
@@ -135,16 +131,16 @@ class TestDataType(base.PyMySQLReplicationTestCase):
         insert_query = "INSERT INTO test VALUES(1, TRUE)"
         event = self.create_and_insert_value(create_query, insert_query)
         self.assertEqual(event.rows[0]["values"]["id"], 1)
-        self.assertEqual(type(event.rows[0]["values"]["test"]), type(True))
-        self.assertEqual(event.rows[0]["values"]["test"], True)
+        self.assertEqual(type(event.rows[0]["values"]["test"]), type(1))
+        self.assertEqual(event.rows[0]["values"]["test"], 1)
 
     def test_tiny_maps_to_boolean_false(self):
         create_query = "CREATE TABLE test (id TINYINT UNSIGNED NOT NULL, test BOOLEAN)"
         insert_query = "INSERT INTO test VALUES(1, FALSE)"
         event = self.create_and_insert_value(create_query, insert_query)
         self.assertEqual(event.rows[0]["values"]["id"], 1)
-        self.assertEqual(type(event.rows[0]["values"]["test"]), type(True))
-        self.assertEqual(event.rows[0]["values"]["test"], False)
+        self.assertEqual(type(event.rows[0]["values"]["test"]), type(0))
+        self.assertEqual(event.rows[0]["values"]["test"], 0)
 
     def test_tiny_maps_to_none(self):
         create_query = "CREATE TABLE test (id TINYINT UNSIGNED NOT NULL, test BOOLEAN)"
@@ -325,8 +321,8 @@ class TestDataType(base.PyMySQLReplicationTestCase):
         create_query = "CREATE TABLE test (test SET('a', 'ba', 'c'), test2 SET('a', 'ba', 'c')) CHARACTER SET latin1 COLLATE latin1_bin;"
         insert_query = "INSERT INTO test VALUES('ba,a,c', 'a,c')"
         event = self.create_and_insert_value(create_query, insert_query)
-        self.assertEqual(event.rows[0]["values"]["test"], {'a', 'ba', 'c'})
-        self.assertEqual(event.rows[0]["values"]["test2"], { 'a', 'c'})
+        self.assertEqual(event.rows[0]["values"]["test"], set(('a', 'ba', 'c')))
+        self.assertEqual(event.rows[0]["values"]["test2"], set(('a', 'c')))
 
     def test_tiny_blob(self):
         create_query = "CREATE TABLE test (test TINYBLOB, test2 TINYTEXT) CHARACTER SET latin1 COLLATE latin1_bin;"
@@ -405,26 +401,26 @@ class TestDataType(base.PyMySQLReplicationTestCase):
         self.connect_conn_control(db)
 
         if platform.python_version_tuple()[0] == "2":
-            str = unichr(233)
+            string = unichr(233)
         else:
-            str = "\u00e9"
+            string = "\u00e9"
 
         create_query = "CREATE TABLE test (test CHAR(12)) CHARACTER SET latin1 COLLATE latin1_bin;"
-        insert_query = b"INSERT INTO test VALUES('" + str.encode('latin-1') + b"');"
+        insert_query = b"INSERT INTO test VALUES('" + string.encode('latin-1') + b"');"
         event = self.create_and_insert_value(create_query, insert_query)
-        self.assertEqual(event.rows[0]["values"]["test"], str)
+        self.assertEqual(event.rows[0]["values"]["test"], string)
 
     def test_encoding_utf8(self):
         if platform.python_version_tuple()[0] == "2":
-            str = unichr(0x20ac)
+            string = unichr(0x20ac)
         else:
-            str = "\u20ac"
+            string = "\u20ac"
 
         create_query = "CREATE TABLE test (test CHAR(12)) CHARACTER SET utf8 COLLATE utf8_bin;"
-        insert_query = b"INSERT INTO test VALUES('" + str.encode('utf-8') + b"')"
+        insert_query = b"INSERT INTO test VALUES('" + string.encode('utf-8') + b"')"
 
         event = self.create_and_insert_value(create_query, insert_query)
-        self.assertMultiLineEqual(event.rows[0]["values"]["test"], str)
+        self.assertMultiLineEqual(event.rows[0]["values"]["test"], string)
 
 
 if __name__ == "__main__":
